@@ -1,11 +1,11 @@
 __copyright__ = 'Copyright (C) 2019'
 __license__ = 'MIT'
-__version__ = "0.1.10"
+__version__ = "0.2.0"
 
 
 def setup(app):
     from .asciinema import Asciinema, ASCIINemaDirective
-    from .asciinema import copy_asset_files, visit_html, visit_man, depart
+    from .asciinema import copy_asset_files, _NODE_VISITORS
 
     app.add_config_value('sphinxcontrib_asciinema_defaults', {}, 'html')
 
@@ -14,5 +14,5 @@ def setup(app):
     app.add_css_file('asciinema-player_2.6.1.css')
     app.add_css_file('asciinema-custom.css')
 
-    app.add_node(Asciinema, man=(visit_man, depart), html=(visit_html, depart))
+    app.add_node(Asciinema, **_NODE_VISITORS)
     app.add_directive('asciinema', ASCIINemaDirective)
